.. image:: https://travis-ci.org/globus/globus-cli.svg?branch=master
    :alt: build status
    :target: https://travis-ci.org/globus/globus-cli
.. image:: https://badge.fury.io/py/globus-cli.svg
    :alt: PyPi Version
    :target: https://badge.fury.io/py/globus-cli
.. image:: https://img.shields.io/pypi/pyversions/globus-cli.svg
    :alt: Supported Pythons
    :target: https://img.shields.io/pypi/pyversions/globus-cli.svg


Globus CLI
==========

A Command Line Interface to `Globus <https://www.globus.org/>`_.

Source Code: https://github.com/globusonline/globus-cli

Installation, Running, Other Documentation: https://globus.github.io/globus-cli

Bugs and Feature Requests
-------------------------

Bugs reports and feature requests are open submission, and should be filed at
https://github.com/globusonline/globus-cli/issues
